import { tagFor } from '@genesislcap/foundation-ui';
import { DI } from '@genesislcap/web-core';
import { HeaderConfig } from '../config/config';
import { defaultTemplateOptions, templateOptionsByDesiginSystemPrefix } from '../config/templates';
import { logger } from '../utils';
/**
 * It's important this file isn't referenced ahead of a `configure` call, otherwise these values may remain fixed at
 * their defaults. Consumers must use the `/config` subpath to help avoid this. Files with references to tags should be
 * lazily loaded. There is an alternative `getTags` utility at the end which could offer another approach, but direct
 * tag exports and inline template references feel cleaner than having to convert all component `template` and `styles`
 * exports to functions to call `getTags` on execution.
 */
/**
 * @internal
 */
export const { templateOptions = defaultTemplateOptions } = DI.getOrCreateDOMContainer().get(HeaderConfig);
/**
 * @internal
 */
export const iconTag = tagFor(templateOptions.icon);
/**
 * @internal
 */
export const buttonTag = tagFor(templateOptions.button);
/**
 * @internal
 */
export const connectionIndicatorTag = tagFor(templateOptions.connectionIndicator);
/**
 * @internal
 */
export const selectTag = tagFor(templateOptions.select);
/**
 * @internal
 */
export const optionTag = tagFor(templateOptions.option);
/**
 * @internal
 */
export const flyoutTag = tagFor(templateOptions.flyout);
/**
 * @internal
 */
export const providerTag = tagFor(templateOptions.provider);
/**
 * @param tagName - The tag name.
 * @param dsPrefix - The design system prefix.
 *
 * @returns The tag for the given tag name and design system prefix.
 *
 * @remarks
 *
 * This function is useful for getting tags when the design system prefix is not known at compile time.
 *
 * @internal
 */
export const getTagHelper = (dsPrefix, tagName) => {
    if (!templateOptionsByDesiginSystemPrefix.hasOwnProperty(dsPrefix)) {
        logger.error(`Design system prefix "${dsPrefix}" not found in template options.`);
        return;
    }
    const currentTemplateOptions = templateOptionsByDesiginSystemPrefix[dsPrefix];
    if (!currentTemplateOptions.hasOwnProperty(tagName)) {
        logger.error(`Tag "${tagName}" not found in template options.`);
        return;
    }
    return tagFor(currentTemplateOptions[tagName]);
};
